
From: James Simmons <jsimmons@infradead.org>

This patch removes drivers that have hardware cursors from calling the
software cursor code.  Also if the driver sets a no hardware cursor flag
then the driver reports a error it someone attempts to use the cursor. 

Signed-off-by: James Simmons <jsimmons@infradead.org>
Cc: "Antonino A. Daplas" <adaplas@pol.net>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 drivers/video/Kconfig              |    4 ----
 drivers/video/i810/i810.h          |    1 -
 drivers/video/i810/i810_main.c     |    6 ++----
 drivers/video/intelfb/intelfb.h    |    1 -
 drivers/video/intelfb/intelfbdrv.c |   21 +++------------------
 drivers/video/intelfb/intelfbhw.c  |    4 ----
 drivers/video/nvidia/nvidia.c      |    4 +---
 7 files changed, 6 insertions(+), 35 deletions(-)

diff -puN drivers/video/i810/i810.h~fbdev-prevent-drivers-that-have-hardware-cursors-from-calling-software-cursor-code drivers/video/i810/i810.h
--- devel/drivers/video/i810/i810.h~fbdev-prevent-drivers-that-have-hardware-cursors-from-calling-software-cursor-code	2005-08-17 18:58:27.000000000 -0700
+++ devel-akpm/drivers/video/i810/i810.h	2005-08-17 18:58:27.000000000 -0700
@@ -201,7 +201,6 @@
 #define HAS_ACCELERATION            2
 #define ALWAYS_SYNC                 4
 #define LOCKUP                      8
-#define USE_HWCUR                  16
 
 struct gtt_data {
 	struct agp_memory *i810_fb_memory;
diff -puN drivers/video/i810/i810_main.c~fbdev-prevent-drivers-that-have-hardware-cursors-from-calling-software-cursor-code drivers/video/i810/i810_main.c
--- devel/drivers/video/i810/i810_main.c~fbdev-prevent-drivers-that-have-hardware-cursors-from-calling-software-cursor-code	2005-08-17 18:58:27.000000000 -0700
+++ devel-akpm/drivers/video/i810/i810_main.c	2005-08-17 18:58:27.000000000 -0700
@@ -1375,7 +1375,6 @@ static int i810fb_set_par(struct fb_info
 	decode_var(&info->var, par);
 	i810_load_regs(par);
 	i810_init_cursor(par);
-
 	encode_fix(&info->fix, info);
 
 	if (info->var.accel_flags && !(par->dev_flags & LOCKUP)) {
@@ -1418,9 +1417,8 @@ static int i810fb_cursor(struct fb_info 
 	struct i810fb_par *par = (struct i810fb_par *)info->par;
 	u8 __iomem *mmio = par->mmio_start_virtual;
 
-	if (!(par->dev_flags & USE_HWCUR) || !info->var.accel_flags ||
-	    par->dev_flags & LOCKUP)
-		return soft_cursor(info, cursor);
+	if (!par->dev_flags & LOCKUP)
+		return -ENXIO;
 
 	if (cursor->image.width > 64 || cursor->image.height > 64)
 		return -ENXIO;
diff -puN drivers/video/intelfb/intelfbdrv.c~fbdev-prevent-drivers-that-have-hardware-cursors-from-calling-software-cursor-code drivers/video/intelfb/intelfbdrv.c
--- devel/drivers/video/intelfb/intelfbdrv.c~fbdev-prevent-drivers-that-have-hardware-cursors-from-calling-software-cursor-code	2005-08-17 18:58:27.000000000 -0700
+++ devel-akpm/drivers/video/intelfb/intelfbdrv.c	2005-08-17 18:58:27.000000000 -0700
@@ -117,14 +117,10 @@
 #include <linux/slab.h>
 #include <linux/delay.h>
 #include <linux/fb.h>
-#include <linux/console.h>
-#include <linux/selection.h>
 #include <linux/ioport.h>
 #include <linux/init.h>
 #include <linux/pci.h>
 #include <linux/vmalloc.h>
-#include <linux/kd.h>
-#include <linux/vt_kern.h>
 #include <linux/pagemap.h>
 #include <linux/version.h>
 
@@ -242,7 +238,7 @@ static int voffset	= 48;
 static char *mode       = NULL;
 
 module_param(accel, bool, S_IRUGO);
-MODULE_PARM_DESC(accel, "Enable console acceleration");
+MODULE_PARM_DESC(accel, "Enable hardware acceleration");
 module_param(vram, int, S_IRUGO);
 MODULE_PARM_DESC(vram, "System RAM to allocate to framebuffer in MiB");
 module_param(voffset, int, S_IRUGO);
@@ -498,7 +494,7 @@ intelfb_pci_register(struct pci_dev *pde
 {
 	struct fb_info *info;
 	struct intelfb_info *dinfo;
-	int i, j, err, dvo;
+	int i, err, dvo;
 	int aperture_size, stolen_size;
 	struct agp_kern_info gtt_info;
 	int agp_memtype;
@@ -845,13 +841,6 @@ intelfb_pci_register(struct pci_dev *pde
 	if (bailearly == 5)
 		bailout(dinfo);
 
-	for (i = 0; i < 16; i++) {
-		j = color_table[i];
-		dinfo->palette[i].red = default_red[j];
-		dinfo->palette[i].green = default_grn[j];
-		dinfo->palette[i].blue = default_blu[j];
-	}
-
 	if (bailearly == 6)
 		bailout(dinfo);
 
@@ -1363,10 +1352,6 @@ intelfb_setcolreg(unsigned regno, unsign
 			green >>= 8;
 			blue >>= 8;
 
-			dinfo->palette[regno].red = red;
-			dinfo->palette[regno].green = green;
-			dinfo->palette[regno].blue = blue;
-
 			intelfbhw_setcolreg(dinfo, regno, red, green, blue,
 					    transp);
 		}
@@ -1499,7 +1484,7 @@ intelfb_cursor(struct fb_info *info, str
 #endif
 
 	if (!dinfo->hwcursor)
-		return soft_cursor(info, cursor);
+		return -ENXIO;
 
 	intelfbhw_cursor_hide(dinfo);
 
diff -puN drivers/video/intelfb/intelfb.h~fbdev-prevent-drivers-that-have-hardware-cursors-from-calling-software-cursor-code drivers/video/intelfb/intelfb.h
--- devel/drivers/video/intelfb/intelfb.h~fbdev-prevent-drivers-that-have-hardware-cursors-from-calling-software-cursor-code	2005-08-17 18:58:27.000000000 -0700
+++ devel-akpm/drivers/video/intelfb/intelfb.h	2005-08-17 18:58:27.000000000 -0700
@@ -234,7 +234,6 @@ struct intelfb_info {
 
 	/* palette */
 	u32 pseudo_palette[17];
-	struct { u8 red, green, blue, pad; } palette[256];
 
 	/* chip info */
 	int pci_chipset;
diff -puN drivers/video/intelfb/intelfbhw.c~fbdev-prevent-drivers-that-have-hardware-cursors-from-calling-software-cursor-code drivers/video/intelfb/intelfbhw.c
--- devel/drivers/video/intelfb/intelfbhw.c~fbdev-prevent-drivers-that-have-hardware-cursors-from-calling-software-cursor-code	2005-08-17 18:58:27.000000000 -0700
+++ devel-akpm/drivers/video/intelfb/intelfbhw.c	2005-08-17 18:58:27.000000000 -0700
@@ -29,14 +29,10 @@
 #include <linux/slab.h>
 #include <linux/delay.h>
 #include <linux/fb.h>
-#include <linux/console.h>
-#include <linux/selection.h>
 #include <linux/ioport.h>
 #include <linux/init.h>
 #include <linux/pci.h>
 #include <linux/vmalloc.h>
-#include <linux/kd.h>
-#include <linux/vt_kern.h>
 #include <linux/pagemap.h>
 #include <linux/version.h>
 
diff -puN drivers/video/Kconfig~fbdev-prevent-drivers-that-have-hardware-cursors-from-calling-software-cursor-code drivers/video/Kconfig
--- devel/drivers/video/Kconfig~fbdev-prevent-drivers-that-have-hardware-cursors-from-calling-software-cursor-code	2005-08-17 18:58:27.000000000 -0700
+++ devel-akpm/drivers/video/Kconfig	2005-08-17 18:58:27.000000000 -0700
@@ -650,7 +650,6 @@ config FB_NVIDIA
 	select FB_CFB_FILLRECT
 	select FB_CFB_COPYAREA
 	select FB_CFB_IMAGEBLIT
-	select FB_SOFT_CURSOR
 	help
 	  This driver supports graphics boards with the nVidia chips, TNT
 	  and newer. For very old chipsets, such as the RIVA128, then use
@@ -681,7 +680,6 @@ config FB_RIVA
 	select FB_CFB_FILLRECT
 	select FB_CFB_COPYAREA
 	select FB_CFB_IMAGEBLIT
-	select FB_SOFT_CURSOR
 	help
 	  This driver supports graphics boards with the nVidia Riva/Geforce
 	  chips.
@@ -720,7 +718,6 @@ config FB_I810
 	select FB_CFB_FILLRECT
 	select FB_CFB_COPYAREA
 	select FB_CFB_IMAGEBLIT
-	select FB_SOFT_CURSOR
 	help
 	  This driver supports the on-board graphics built in to the Intel 810 
           and 815 chipsets.  Say Y if you have and plan to use such a board.
@@ -763,7 +760,6 @@ config FB_INTEL
 	select FB_CFB_FILLRECT
 	select FB_CFB_COPYAREA
 	select FB_CFB_IMAGEBLIT
-	select FB_SOFT_CURSOR
 	help
 	  This driver supports the on-board graphics built in to the Intel
           830M/845G/852GM/855GM/865G chipsets.
diff -puN drivers/video/nvidia/nvidia.c~fbdev-prevent-drivers-that-have-hardware-cursors-from-calling-software-cursor-code drivers/video/nvidia/nvidia.c
--- devel/drivers/video/nvidia/nvidia.c~fbdev-prevent-drivers-that-have-hardware-cursors-from-calling-software-cursor-code	2005-08-17 18:58:27.000000000 -0700
+++ devel-akpm/drivers/video/nvidia/nvidia.c	2005-08-17 18:58:27.000000000 -0700
@@ -893,7 +893,7 @@ static int nvidiafb_cursor(struct fb_inf
 	int i, set = cursor->set;
 	u16 fg, bg;
 
-	if (cursor->image.width > MAX_CURS || cursor->image.height > MAX_CURS)
+	if (!hwcur || cursor->image.width > MAX_CURS || cursor->image.height > MAX_CURS)
 		return -ENXIO;
 
 	NVShowHideCursor(par, 0);
@@ -1356,8 +1356,6 @@ static int __devinit nvidia_set_fbinfo(s
 	info->pixmap.size = 8 * 1024;
 	info->pixmap.flags = FB_PIXMAP_SYSTEM;
 
-	if (!hwcur)
-		info->fbops->fb_cursor = soft_cursor;
 	info->var.accel_flags = (!noaccel);
 
 	switch (par->Architecture) {
_
